package com.m2u.rsa.helper;

import java.util.Properties;

import com.rsa.csd.ws.APIType;
import com.rsa.csd.ws.Amount;
import com.rsa.csd.ws.AuthorizationMethod;
import com.rsa.csd.ws.DeviceRequest;
import com.rsa.csd.ws.EventData;
import com.rsa.csd.ws.EventDataList;
import com.rsa.csd.ws.EventType;
import com.rsa.csd.ws.GenericActionType;
import com.rsa.csd.ws.GenericActionTypeList;
import com.rsa.csd.ws.IdentificationData;
import com.rsa.csd.ws.MessageHeader;
import com.rsa.csd.ws.MessageVersion;
import com.rsa.csd.ws.RequestType;
import com.rsa.csd.ws.SecurityHeader;
import com.rsa.csd.ws.TransactionData;
import com.rsa.csd.ws.UserAddress;
import com.rsa.csd.ws.UserData;
import com.rsa.csd.ws.UserName;
import com.rsa.csd.ws.UserStatus;
import com.rsa.csd.ws.WSUserType;

public class CommonHelper implements java.io.Serializable {
	private static final long serialVersionUID = 7016444456049600812L;

	private DeviceRequest DR = new DeviceRequest();
	private IdentificationData ID = new IdentificationData();
	private MessageHeader MH = new MessageHeader();
	private SecurityHeader SH = new SecurityHeader();
	private UserData UD = new UserData();
	private EventDataList EDL = new EventDataList();
	private GenericActionTypeList GATL = new GenericActionTypeList();

	M2URSACfg cfg = M2URSACfg.getInstance();
	Properties prop = new Properties();

	public CommonHelper() {
		cfg = M2URSACfg.getInstance();
		prop = cfg.getprop();
	}

	public MessageHeader setMessage(String requestId, RequestType requestType,
			String timeStamp) {

		String api = prop.getProperty("APITYPE");
		String version = prop.getProperty("VERSION");

		MH.setApiType(APIType.fromString(api));
		MH.setRequestId(requestId);
		MH.setRequestType(requestType);
		MH.setTimeStamp(timeStamp);
		MH.setVersion(MessageVersion.fromString(version));
		return MH;

	}

	public IdentificationData setIdent(String clientSessionId,
			String clientTransactionId, Boolean delegated, String groupName,
			String newUserName, String orgName, String sessionId,
			String transactionId, String userCountry, String userLanguage,
			String userLoginName, String userName, UserStatus userStatus,
			WSUserType userType) {
		ID.setClientSessionId(clientSessionId);
		ID.setClientTransactionId(clientTransactionId);
		// ID.setDelegated(delegated);
		ID.setGroupName(groupName);
		// ID.setNewUserName(newUserName);
		ID.setOrgName(orgName);
		ID.setSessionId(sessionId);
		ID.setTransactionId(transactionId);
		ID.setUserCountry(userCountry);
		ID.setUserLanguage(userLanguage);
		ID.setUserLoginName(userLoginName);
		ID.setUserName(userName);
		ID.setUserStatus(userStatus);
		ID.setUserType(userType);

		return ID;

	}

	public DeviceRequest setDevice(String devicePrint,
			String deviceTokenCookie, String deviceTokenFSO, String httpAccept,
			String httpAcceptChars, String httpAcceptEncoding,
			String httpAcceptLanguage, String httpReferrer, String ipAddress,
			String userAgent) {

		DR.setDevicePrint(devicePrint);
		DR.setDeviceTokenCookie(deviceTokenCookie);
		DR.setDeviceTokenFSO(deviceTokenFSO);
		DR.setHttpAccept(httpAccept);
		DR.setHttpAcceptChars(httpAcceptChars);
		DR.setHttpAcceptEncoding(httpAcceptEncoding);
		DR.setHttpAcceptLanguage(httpAcceptLanguage);
		DR.setHttpReferrer(httpReferrer);
		DR.setIpAddress(ipAddress);
		DR.setUserAgent(userAgent);
		return DR;
	}

	public SecurityHeader setSecurityHeader() {

		String callerCredential = prop.getProperty("CREDENTIAL");
		String callerId = prop.getProperty("CALLERID");
		String method = prop.getProperty("METHOD");

		SH.setCallerCredential(callerCredential);
		SH.setCallerId(callerId);
		SH.setMethod(AuthorizationMethod.fromString(method));
		return SH;

	}

	/*********************************************************/

	public EventDataList setEventData(String eventDescription,
			EventType eventType) {

		EventData ED = new EventData();

		ED.setEventDescription(eventDescription);
		ED.setEventType(eventType);
		EventData[] eData = { ED };
		EDL.setEventData(eData);
		return EDL;
	}

	public EventDataList setEventData(String eventDescription,
			EventType eventType, TransactionData transactionData) {
		EventData ED = new EventData();
		ED.setEventDescription(eventDescription);
		ED.setEventType(eventType);
		ED.setTransactionData(transactionData);
		EventData[] eData = { ED };
		EDL.setEventData(eData);
		return EDL;
	}

	public UserData setUserData(Boolean business, String lastAccountOpenDate,
			String lastOnlineServicePasswordChangeDate,
			String onlineServiceEnrollDate, Amount totalAvailableBalance,
			Amount totalCreditLimit, Amount totalCreditsUsed,
			UserAddress userAddress, UserName userNameData, Boolean VIP) {

		UD.setBusiness(business);
		UD.setLastAccountOpenDate(lastAccountOpenDate);
		UD
				.setLastOnlineServicePasswordChangeDate(lastOnlineServicePasswordChangeDate);
		UD.setOnlineServiceEnrollDate(onlineServiceEnrollDate);
		UD.setTotalAvailableBalance(totalAvailableBalance);
		UD.setTotalCreditLimit(totalCreditLimit);
		UD.setTotalCreditsUsed(totalCreditsUsed);
		UD.setUserAddress(userAddress);
		UD.setUserNameData(userNameData);
		UD.setVIP(VIP);
		return UD;
	}

	public GenericActionTypeList setGenericActionType(GenericActionType[] Gat) {
		GenericActionType[] GAT = Gat;
		GATL.setGenericActionTypes(GAT);
		return GATL;

	}

}
